#!/usr/bin/env python3
#                            _                _____
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#
#
"""
This is the static var file.
"""

NATIONS = {'Afghanistan': 'AF',
           'Albania': 'AL',
           'Algeria': 'DZ',
           'American Samoa': 'AS',
           'Andorra': 'AD',
           'Angola': 'AO',
           'Anguilla': 'AI',
           'Antarctica': 'AQ',
           'Antigua and Barbuda': 'AG',
           'Argentina': 'AR',
           'Armenia': 'AM',
           'Aruba': 'AW',
           'Aruba': 'AW',
           'Australia': 'AU',
           'Austria': 'AT',
           'Azerbaijan': 'AZ',
           'Bahamas': 'BS',
           'Bahrain': 'BH',
           'Bangladesh': 'BD',
           'Barbados': 'BB',
           'Belarus': 'BY',
           'Belgium': 'BE',
           'Belize': 'BZ',
           'Benin': 'BJ',
           'Bermuda': 'BM',
           'Bhutan': 'BT',
           'Bolivia, Plurinational State of': 'BO',
           'Bonaire, Sint Eustatius and Saba': 'BQ',
           'Bosnia and Herzegovina': 'BA',
           'Botswana': 'BW',
           'Bouvet Island': 'BV',
           'Brazil': 'BR',
           'British Indian Ocean Territory': 'IO',
           'Brunei Darussalam': 'BN',
           'Bulgaria': 'BG',
           'Burkina Faso': 'BF',
           'Burundi': 'BI',
           'Cambodia': 'KH',
           'Cameroon': 'CM',
           'Canada': 'CA',
           'Cape Verde': 'CV',
           'Cayman Islands': 'KY',
           'Central African Republic': 'CF',
           'Chad': 'TD',
           'Chile': 'CL',
           'China': 'CN',
           'Christmas Island': 'CX',
           'Cocos (Keeling) Islands': 'CC',
           'Colombia': 'CO',
           'Comoros': 'KM',
           'Congo': 'CG',
           'Congo, the Democratic Republic of the': 'CD',
           'Cook Islands': 'CK',
           'Costa Rica': 'CR',
           'Country name': 'Code',
           'Croatia': 'HR',
           'Cuba': 'CU',
           'Curaçao': 'CW',
           'Cyprus': 'CY',
           'Czech Republic': 'CZ',
           "Côte d'Ivoire": 'CI',
           'Denmark': 'DK',
           'Djibouti': 'DJ',
           'Dominica': 'DM',
           'Dominican Republic': 'DO',
           'Ecuador': 'EC',
           'Egypt': 'EG',
           'El Salvador': 'SV',
           'Equatorial Guinea': 'GQ',
           'Eritrea': 'ER',
           'Estonia': 'EE',
           'Ethiopia': 'ET',
           'Falkland Islands (Malvinas)': 'FK',
           'Faroe Islands': 'FO',
           'Fiji': 'FJ',
           'Finland': 'FI',
           'France': 'FR',
           'French Guiana': 'GF',
           'French Polynesia': 'PF',
           'French Southern Territories': 'TF',
           'Gabon': 'GA',
           'Gambia': 'GM',
           'Georgia': 'GE',
           'Germany': 'DE',
           'Ghana': 'GH',
           'Gibraltar': 'GI',
           'Greece': 'GR',
           'Greenland': 'GL',
           'Grenada': 'GD',
           'Guadeloupe': 'GP',
           'Guam': 'GU',
           'Guatemala': 'GT',
           'Guernsey': 'GG',
           'Guinea': 'GN',
           'Guinea-Bissau': 'GW',
           'Guyana': 'GY',
           'Haiti': 'HT',
           'Heard Island and McDonald Islands': 'HM',
           'Holy See (Vatican City State)': 'VA',
           'Honduras': 'HN',
           'Hong Kong': 'HK',
           'Hungary': 'HU',
           'ISO 3166-2:GB': '(.uk)',
           'Iceland': 'IS',
           'India': 'IN',
           'Indonesia': 'ID',
           'Iran, Islamic Republic of': 'IR',
           'Iraq': 'IQ',
           'Ireland': 'IE',
           'Isle of Man': 'IM',
           'Israel': 'IL',
           'Italy': 'IT',
           'Jamaica': 'JM',
           'Japan': 'JP',
           'Jersey': 'JE',
           'Jordan': 'JO',
           'Kazakhstan': 'KZ',
           'Kenya': 'KE',
           'Kiribati': 'KI',
           "Korea, Democratic People's Republic of": 'KP',
           'Korea, Republic of': 'KR',
           'Kuwait': 'KW',
           'Kyrgyzstan': 'KG',
           "Lao People's Democratic Republic": 'LA',
           'Latvia': 'LV',
           'Lebanon': 'LB',
           'Lesotho': 'LS',
           'Liberia': 'LR',
           'Libya': 'LY',
           'Liechtenstein': 'LI',
           'Lithuania': 'LT',
           'Luxembourg': 'LU',
           'Macao': 'MO',
           'Macedonia, the former Yugoslav Republic of': 'MK',
           'Madagascar': 'MG',
           'Malawi': 'MW',
           'Malaysia': 'MY',
           'Maldives': 'MV',
           'Mali': 'ML',
           'Malta': 'MT',
           'Marshall Islands': 'MH',
           'Martinique': 'MQ',
           'Mauritania': 'MR',
           'Mauritius': 'MU',
           'Mayotte': 'YT',
           'Mexico': 'MX',
           'Micronesia, Federated States of': 'FM',
           'Moldova, Republic of': 'MD',
           'Monaco': 'MC',
           'Mongolia': 'MN',
           'Montenegro': 'ME',
           'Montserrat': 'MS',
           'Morocco': 'MA',
           'Mozambique': 'MZ',
           'Myanmar': 'MM',
           'Namibia': 'NA',
           'Nauru': 'NR',
           'Nepal': 'NP',
           'Netherlands': 'NL',
           'New Caledonia': 'NC',
           'New Zealand': 'NZ',
           'Nicaragua': 'NI',
           'Niger': 'NE',
           'Nigeria': 'NG',
           'Niue': 'NU',
           'Norfolk Island': 'NF',
           'Northern Mariana Islands': 'MP',
           'Norway': 'NO',
           'Oman': 'OM',
           'Pakistan': 'PK',
           'Palau': 'PW',
           'Palestine, State of': 'PS',
           'Panama': 'PA',
           'Papua New Guinea': 'PG',
           'Paraguay': 'PY',
           'Peru': 'PE',
           'Philippines': 'PH',
           'Pitcairn': 'PN',
           'Poland': 'PL',
           'Portugal': 'PT',
           'Puerto Rico': 'PR',
           'Qatar': 'QA',
           'Romania': 'RO',
           'Russian Federation': 'RU',
           'Rwanda': 'RW',
           'Réunion': 'RE',
           'Saint Barthélemy': 'BL',
           'Saint Helena, Ascension and Tristan da Cunha': 'SH',
           'Saint Kitts and Nevis': 'KN',
           'Saint Lucia': 'LC',
           'Saint Martin (French part)': 'MF',
           'Saint Pierre and Miquelon': 'PM',
           'Saint Vincent and the Grenadines': 'VC',
           'Samoa': 'WS',
           'San Marino': 'SM',
           'Sao Tome and Principe': 'ST',
           'Saudi Arabia': 'SA',
           'Senegal': 'SN',
           'Serbia': 'RS',
           'Seychelles': 'SC',
           'Sierra Leone': 'SL',
           'Singapore': 'SG',
           'Sint Maarten (Dutch part)': 'SX',
           'Slovakia': 'SK',
           'Slovenia': 'SI',
           'Solomon Islands': 'SB',
           'Somalia': 'SO',
           'South Africa': 'ZA',
           'South Georgia and the South Sandwich Islands': 'GS',
           'South Sudan': 'SS',
           'Spain': 'ES',
           'Sri Lanka': 'LK',
           'Sudan': 'SD',
           'Suriname': 'SR',
           'Svalbard and Jan Mayen': 'SJ',
           'Swaziland': 'SZ',
           'Sweden': 'SE',
           'Switzerland': 'CH',
           'Syrian Arab Republic': 'SY',
           'Taiwan, Province of China': 'TW',
           'Tajikistan': 'TJ',
           'Tanzania, United Republic of': 'TZ',
           'Thailand': 'TH',
           'Timor-Leste': 'TL',
           'Togo': 'TG',
           'Tokelau': 'TK',
           'Tonga': 'TO',
           'Trinidad and Tobago': 'TT',
           'Tunisia': 'TN',
           'Turkey': 'TR',
           'Turkmenistan': 'TM',
           'Turks and Caicos Islands': 'TC',
           'Tuvalu': 'TV',
           'Uganda': 'UG',
           'Ukraine': 'UA',
           'United Arab Emirates': 'AE',
           'United Kingdom': 'GB',
           'United States': 'US',
           'United States Minor Outlying Islands': 'UM',
           'Uruguay': 'UY',
           'Uzbekistan': 'UZ',
           'Vanuatu': 'VU',
           'Venezuela, Bolivarian Republic of': 'VE',
           'Viet Nam': 'VN',
           'Virgin Islands, British': 'VG',
           'Virgin Islands, U.S.': 'VI',
           'Wallis and Futuna': 'WF',
           'Western Sahara': 'EH',
           'Yemen': 'YE',
           'Zambia': 'ZM',
           'Zimbabwe': 'ZW',
           'Åland Islands': 'AX'
           }

flag_iso = (
    'AF', 'AL', 'DZ', 'AD', 'AO', 'AG', 'AR', 'AM', 'AU', 'AT', 'AZ', 'BS', 'BH', 'BD', 'BB', 'BY', 'BE', 'BZ', 'BJ',
    'BT',
    'BO', 'BA', 'BW', 'BR', 'BN', 'BG', 'BF', 'BI', 'KH', 'CM', 'CA', 'CV', 'CF', 'TD', 'CL', 'CN', 'CO', 'KM', 'CD',
    'CR',
    'CI', 'HR', 'CU', 'CY', 'CZ', 'DK', 'DJ', 'DM', 'DO', 'TL', 'EC', 'EG', 'SV', 'GQ', 'ER', 'EE', 'ET', 'FJ', 'FI',
    'FR',
    'PF', 'GA', 'GM', 'GE', 'DE', 'GH', 'GI', 'GR', 'GL', 'GD', 'GP', 'GT', 'GN', 'GW', 'GY', 'HT', 'HN', 'HK', 'HU',
    'IS',
    'IN', 'ID', 'IR', 'IQ', 'IE', 'IL', 'IT', 'JM', 'JP', 'JO', 'KZ', 'KE', 'KI', 'KP', 'KR', 'KW', 'KG', 'LA', 'LV',
    'LB',
    'LS', 'LR', 'LY', 'LI', 'LT', 'LU', 'MO', 'MK', 'MG', 'MW', 'MY', 'MV', 'ML', 'MT', 'MH', 'MQ', 'MR', 'MU', 'MX',
    'FM',
    'MD', 'MC', 'MN', 'ME', 'MA', 'MZ', 'MM', 'NA', 'NR', 'NP', 'NL', 'NC', 'NZ', 'NI', 'NE', 'NG', 'MP', 'NO', 'OM',
    'PK',
    'PW', 'PS', 'PA', 'PG', 'PY', 'PE', 'PH', 'PL', 'PT', 'PR', 'QA', 'RE', 'RO', 'RU', 'RW', 'KN', 'LC', 'WS', 'SM',
    'ST',
    'SA', 'SN', 'RS', 'SC', 'SL', 'SG', 'SK', 'SI', 'SB', 'SO', 'ZA', 'ES', 'LK', 'VC', 'SD', 'SR', 'SZ', 'SE', 'CH',
    'SY',
    'TW', 'TJ', 'TZ', 'TH', 'TG', 'TO', 'TT', 'TN', 'TR', 'TM', 'TV', 'UG', 'UA', 'AE', 'GB', 'US', 'UY', 'UZ', 'VU',
    'VA',
    'VE', 'VN', 'VG', 'VI', 'EH', 'YE', 'ZM', 'ZW')
